@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-anki" "4.0.3"
+(define-package "org-anki" "20260209.1249"
   "Synchronize org-mode entries to Anki."
   '((emacs   "27.1")
     (request "0.3.2")
